//line parser.y:2
package main

import __yyfmt__ "fmt"

//line parser.y:2
import (
	"bytes"
	"fmt"
	"io"
	"os"
)

type node struct {
	name       string
	children   []node
	attributes map[string]string
}

func (n node) String() string {
	buf := new(bytes.Buffer)
	n.print(buf, " ")
	return buf.String()
}

func (n node) print(out io.Writer, indent string) {
	if len(n.attributes) > 0 {
		fmt.Fprintf(out, "\n%v%v %s", indent, n.name, n.attributes)
	} else {
		fmt.Fprintf(out, "\n%v%v", indent, n.name)
	}
	for _, nn := range n.children {
		nn.print(out, indent+"  ")
	}
}

func Node(name string) node {
	return node{name: name, attributes: make(map[string]string)}
}

func (n node) append(nn ...node) node {
	n.children = append(n.children, nn...)
	return n
}

func (n node) attribute(key string, value string) node {
	n.attributes[key] = value
	return n
}

//line parser.y:50
type yySymType struct {
	yys   int
	node  node
	token string
	value string
}

const T_INCLUDE = 57346
const T_INCLUDE_ONCE = 57347
const T_EVAL = 57348
const T_REQUIRE = 57349
const T_REQUIRE_ONCE = 57350
const T_LOGICAL_OR = 57351
const T_LOGICAL_XOR = 57352
const T_LOGICAL_AND = 57353
const T_PRINT = 57354
const T_YIELD = 57355
const T_DOUBLE_ARROW = 57356
const T_YIELD_FROM = 57357
const T_PLUS_EQUAL = 57358
const T_MINUS_EQUAL = 57359
const T_MUL_EQUAL = 57360
const T_DIV_EQUAL = 57361
const T_CONCAT_EQUAL = 57362
const T_MOD_EQUAL = 57363
const T_AND_EQUAL = 57364
const T_OR_EQUAL = 57365
const T_XOR_EQUAL = 57366
const T_SL_EQUAL = 57367
const T_SR_EQUAL = 57368
const T_POW_EQUAL = 57369
const T_COALESCE = 57370
const T_BOOLEAN_OR = 57371
const T_BOOLEAN_AND = 57372
const T_IS_EQUAL = 57373
const T_IS_NOT_EQUAL = 57374
const T_IS_IDENTICAL = 57375
const T_IS_NOT_IDENTICAL = 57376
const T_SPACESHIP = 57377
const T_IS_SMALLER_OR_EQUAL = 57378
const T_IS_GREATER_OR_EQUAL = 57379
const T_SL = 57380
const T_SR = 57381
const T_INSTANCEOF = 57382
const T_INC = 57383
const T_DEC = 57384
const T_INT_CAST = 57385
const T_DOUBLE_CAST = 57386
const T_STRING_CAST = 57387
const T_ARRAY_CAST = 57388
const T_OBJECT_CAST = 57389
const T_BOOL_CAST = 57390
const T_UNSET_CAST = 57391
const T_POW = 57392
const T_NEW = 57393
const T_CLONE = 57394
const T_NOELSE = 57395
const T_ELSEIF = 57396
const T_ELSE = 57397
const T_ENDIF = 57398
const T_STATIC = 57399
const T_ABSTRACT = 57400
const T_FINAL = 57401
const T_PRIVATE = 57402
const T_PROTECTED = 57403
const T_PUBLIC = 57404
const T_EXIT = 57405
const T_IF = 57406
const T_LNUMBER = 57407
const T_DNUMBER = 57408
const T_STRING = 57409
const T_STRING_VARNAME = 57410
const T_VARIABLE = 57411
const T_NUM_STRING = 57412
const T_INLINE_HTML = 57413
const T_CHARACTER = 57414
const T_BAD_CHARACTER = 57415
const T_ENCAPSED_AND_WHITESPACE = 57416
const T_CONSTANT_ENCAPSED_STRING = 57417
const T_ECHO = 57418
const T_DO = 57419
const T_WHILE = 57420
const T_ENDWHILE = 57421
const T_FOR = 57422
const T_ENDFOR = 57423
const T_FOREACH = 57424
const T_ENDFOREACH = 57425
const T_DECLARE = 57426
const T_ENDDECLARE = 57427
const T_AS = 57428
const T_SWITCH = 57429
const T_ENDSWITCH = 57430
const T_CASE = 57431
const T_DEFAULT = 57432
const T_BREAK = 57433
const T_CONTINUE = 57434
const T_GOTO = 57435
const T_FUNCTION = 57436
const T_CONST = 57437
const T_RETURN = 57438
const T_TRY = 57439
const T_CATCH = 57440
const T_FINALLY = 57441
const T_THROW = 57442
const T_USE = 57443
const T_INSTEADOF = 57444
const T_GLOBAL = 57445
const T_VAR = 57446
const T_UNSET = 57447
const T_ISSET = 57448
const T_EMPTY = 57449
const T_HALT_COMPILER = 57450
const T_CLASS = 57451
const T_TRAIT = 57452
const T_INTERFACE = 57453
const T_EXTENDS = 57454
const T_IMPLEMENTS = 57455
const T_OBJECT_OPERATOR = 57456
const T_LIST = 57457
const T_ARRAY = 57458
const T_CALLABLE = 57459
const T_CLASS_C = 57460
const T_TRAIT_C = 57461
const T_METHOD_C = 57462
const T_FUNC_C = 57463
const T_LINE = 57464
const T_FILE = 57465
const T_COMMENT = 57466
const T_DOC_COMMENT = 57467
const T_OPEN_TAG = 57468
const T_OPEN_TAG_WITH_ECHO = 57469
const T_CLOSE_TAG = 57470
const T_WHITESPACE = 57471
const T_START_HEREDOC = 57472
const T_END_HEREDOC = 57473
const T_DOLLAR_OPEN_CURLY_BRACES = 57474
const T_CURLY_OPEN = 57475
const T_PAAMAYIM_NEKUDOTAYIM = 57476
const T_NAMESPACE = 57477
const T_NS_C = 57478
const T_DIR = 57479
const T_NS_SEPARATOR = 57480
const T_ELLIPSIS = 57481

var yyToknames = [...]string{
	"$end",
	"error",
	"$unk",
	"T_INCLUDE",
	"T_INCLUDE_ONCE",
	"T_EVAL",
	"T_REQUIRE",
	"T_REQUIRE_ONCE",
	"','",
	"T_LOGICAL_OR",
	"T_LOGICAL_XOR",
	"T_LOGICAL_AND",
	"T_PRINT",
	"T_YIELD",
	"T_DOUBLE_ARROW",
	"T_YIELD_FROM",
	"'='",
	"T_PLUS_EQUAL",
	"T_MINUS_EQUAL",
	"T_MUL_EQUAL",
	"T_DIV_EQUAL",
	"T_CONCAT_EQUAL",
	"T_MOD_EQUAL",
	"T_AND_EQUAL",
	"T_OR_EQUAL",
	"T_XOR_EQUAL",
	"T_SL_EQUAL",
	"T_SR_EQUAL",
	"T_POW_EQUAL",
	"'?'",
	"':'",
	"T_COALESCE",
	"T_BOOLEAN_OR",
	"T_BOOLEAN_AND",
	"'|'",
	"'^'",
	"'&'",
	"T_IS_EQUAL",
	"T_IS_NOT_EQUAL",
	"T_IS_IDENTICAL",
	"T_IS_NOT_IDENTICAL",
	"T_SPACESHIP",
	"'<'",
	"T_IS_SMALLER_OR_EQUAL",
	"'>'",
	"T_IS_GREATER_OR_EQUAL",
	"T_SL",
	"T_SR",
	"'+'",
	"'-'",
	"'.'",
	"'*'",
	"'/'",
	"'%'",
	"'!'",
	"T_INSTANCEOF",
	"'~'",
	"T_INC",
	"T_DEC",
	"T_INT_CAST",
	"T_DOUBLE_CAST",
	"T_STRING_CAST",
	"T_ARRAY_CAST",
	"T_OBJECT_CAST",
	"T_BOOL_CAST",
	"T_UNSET_CAST",
	"'@'",
	"T_POW",
	"'['",
	"T_NEW",
	"T_CLONE",
	"T_NOELSE",
	"T_ELSEIF",
	"T_ELSE",
	"T_ENDIF",
	"T_STATIC",
	"T_ABSTRACT",
	"T_FINAL",
	"T_PRIVATE",
	"T_PROTECTED",
	"T_PUBLIC",
	"T_EXIT",
	"T_IF",
	"T_LNUMBER",
	"T_DNUMBER",
	"T_STRING",
	"T_STRING_VARNAME",
	"T_VARIABLE",
	"T_NUM_STRING",
	"T_INLINE_HTML",
	"T_CHARACTER",
	"T_BAD_CHARACTER",
	"T_ENCAPSED_AND_WHITESPACE",
	"T_CONSTANT_ENCAPSED_STRING",
	"T_ECHO",
	"T_DO",
	"T_WHILE",
	"T_ENDWHILE",
	"T_FOR",
	"T_ENDFOR",
	"T_FOREACH",
	"T_ENDFOREACH",
	"T_DECLARE",
	"T_ENDDECLARE",
	"T_AS",
	"T_SWITCH",
	"T_ENDSWITCH",
	"T_CASE",
	"T_DEFAULT",
	"T_BREAK",
	"T_CONTINUE",
	"T_GOTO",
	"T_FUNCTION",
	"T_CONST",
	"T_RETURN",
	"T_TRY",
	"T_CATCH",
	"T_FINALLY",
	"T_THROW",
	"T_USE",
	"T_INSTEADOF",
	"T_GLOBAL",
	"T_VAR",
	"T_UNSET",
	"T_ISSET",
	"T_EMPTY",
	"T_HALT_COMPILER",
	"T_CLASS",
	"T_TRAIT",
	"T_INTERFACE",
	"T_EXTENDS",
	"T_IMPLEMENTS",
	"T_OBJECT_OPERATOR",
	"T_LIST",
	"T_ARRAY",
	"T_CALLABLE",
	"T_CLASS_C",
	"T_TRAIT_C",
	"T_METHOD_C",
	"T_FUNC_C",
	"T_LINE",
	"T_FILE",
	"T_COMMENT",
	"T_DOC_COMMENT",
	"T_OPEN_TAG",
	"T_OPEN_TAG_WITH_ECHO",
	"T_CLOSE_TAG",
	"T_WHITESPACE",
	"T_START_HEREDOC",
	"T_END_HEREDOC",
	"T_DOLLAR_OPEN_CURLY_BRACES",
	"T_CURLY_OPEN",
	"T_PAAMAYIM_NEKUDOTAYIM",
	"T_NAMESPACE",
	"T_NS_C",
	"T_DIR",
	"T_NS_SEPARATOR",
	"T_ELLIPSIS",
	"';'",
	"'{'",
	"'}'",
	"'('",
	"')'",
	"']'",
	"'$'",
}
var yyStatenames = [...]string{}

const yyEofCode = 1
const yyErrCode = 2
const yyInitialStackSize = 16

//line parser.y:748
const src = `<?php

try {

} catch(\Exception | RuntimeException $e) {

} finally {
    
}

`

func main() {
	yyDebug = 0
	yyErrorVerbose = true
	l := newLexer(bytes.NewBufferString(src), os.Stdout, "file.name")
	yyParse(l)
}

//line yacctab:1
var yyExca = [...]int{
	-1, 1,
	1, -1,
	-2, 0,
	-1, 87,
	159, 46,
	-2, 281,
	-1, 294,
	38, 0,
	39, 0,
	40, 0,
	41, 0,
	42, 0,
	-2, 253,
	-1, 295,
	38, 0,
	39, 0,
	40, 0,
	41, 0,
	42, 0,
	-2, 254,
	-1, 296,
	38, 0,
	39, 0,
	40, 0,
	41, 0,
	42, 0,
	-2, 255,
	-1, 297,
	38, 0,
	39, 0,
	40, 0,
	41, 0,
	42, 0,
	-2, 256,
	-1, 298,
	38, 0,
	39, 0,
	40, 0,
	41, 0,
	42, 0,
	-2, 257,
	-1, 299,
	43, 0,
	44, 0,
	45, 0,
	46, 0,
	-2, 258,
	-1, 300,
	43, 0,
	44, 0,
	45, 0,
	46, 0,
	-2, 259,
	-1, 301,
	43, 0,
	44, 0,
	45, 0,
	46, 0,
	-2, 260,
	-1, 302,
	43, 0,
	44, 0,
	45, 0,
	46, 0,
	-2, 261,
	-1, 361,
	163, 193,
	-2, 198,
}

const yyPrivate = 57344

const yyLast = 4191

var yyAct = [...]int{

	23, 149, 427, 458, 403, 481, 400, 69, 429, 398,
	385, 401, 263, 406, 418, 311, 307, 156, 156, 156,
	258, 146, 167, 4, 166, 163, 160, 34, 65, 463,
	527, 522, 512, 387, 151, 489, 488, 453, 454, 479,
	227, 453, 454, 230, 231, 232, 233, 234, 161, 236,
	66, 238, 239, 240, 241, 242, 243, 244, 245, 246,
	247, 248, 249, 250, 66, 389, 438, 383, 228, 229,
	511, 469, 358, 467, 426, 361, 344, 171, 173, 172,
	227, 424, 69, 236, 66, 238, 239, 248, 249, 319,
	484, 276, 317, 237, 452, 148, 252, 195, 235, 196,
	169, 170, 174, 176, 175, 188, 189, 186, 187, 190,
	191, 192, 193, 194, 184, 185, 178, 179, 177, 180,
	182, 183, 251, 226, 381, 199, 198, 67, 197, 154,
	388, 153, 150, 409, 363, 181, 482, 528, 499, 470,
	362, 67, 402, 316, 404, 405, 273, 271, 200, 529,
	520, 261, 507, 69, 265, 266, 495, 485, 478, 450,
	447, 67, 422, 408, 148, 421, 407, 419, 444, 417,
	277, 278, 279, 280, 281, 282, 283, 284, 285, 286,
	287, 288, 289, 290, 291, 292, 293, 294, 295, 296,
	297, 298, 299, 300, 301, 302, 303, 305, 148, 309,
	345, 320, 313, 269, 268, 267, 254, 253, 475, 255,
	63, 64, 322, 324, 325, 326, 327, 328, 329, 330,
	331, 332, 333, 334, 335, 308, 357, 336, 318, 423,
	416, 262, 408, 436, 437, 407, 338, 514, 339, 501,
	164, 275, 486, 453, 454, 148, 312, 404, 405, 456,
	453, 454, 341, 380, 342, 315, 314, 205, 208, 210,
	209, 203, 206, 207, 483, 181, 408, 441, 202, 407,
	472, 446, 321, 36, 155, 350, 464, 167, 191, 192,
	193, 194, 184, 185, 178, 179, 177, 180, 182, 183,
	513, 517, 157, 158, 359, 274, 272, 270, 348, 349,
	161, 351, 439, 181, 204, 353, 184, 185, 178, 179,
	177, 180, 182, 183, 355, 346, 259, 354, 364, 5,
	365, 71, 260, 366, 367, 8, 72, 181, 1, 178,
	179, 177, 180, 182, 183, 180, 182, 183, 435, 496,
	395, 371, 390, 310, 430, 376, 265, 378, 181, 428,
	306, 181, 165, 382, 162, 159, 379, 502, 377, 264,
	394, 373, 11, 33, 374, 10, 32, 38, 35, 397,
	396, 471, 384, 399, 393, 30, 256, 415, 391, 2,
	147, 3, 68, 308, 386, 201, 474, 440, 0, 413,
	431, 0, 0, 0, 434, 0, 420, 211, 212, 213,
	214, 216, 217, 218, 219, 220, 221, 222, 223, 215,
	0, 0, 0, 0, 442, 425, 448, 0, 265, 0,
	0, 443, 0, 0, 0, 0, 0, 431, 0, 462,
	451, 445, 0, 0, 455, 461, 457, 0, 224, 225,
	0, 0, 0, 0, 459, 0, 0, 0, 477, 473,
	0, 0, 386, 0, 480, 0, 0, 0, 476, 0,
	466, 0, 487, 0, 0, 431, 491, 0, 431, 0,
	494, 0, 498, 490, 497, 0, 0, 0, 0, 500,
	0, 0, 0, 506, 0, 0, 505, 81, 82, 83,
	84, 85, 509, 88, 89, 90, 86, 87, 0, 62,
	503, 516, 0, 0, 0, 0, 518, 519, 0, 459,
	0, 0, 431, 0, 521, 0, 0, 0, 525, 523,
	510, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	530, 0, 42, 43, 0, 0, 0, 0, 44, 91,
	45, 40, 41, 52, 53, 54, 55, 56, 57, 58,
	59, 0, 0, 92, 79, 0, 95, 96, 97, 73,
	74, 75, 76, 77, 78, 93, 94, 0, 0, 70,
	0, 66, 0, 0, 0, 0, 0, 0, 98, 99,
	100, 101, 102, 103, 104, 105, 106, 107, 108, 125,
	126, 127, 128, 129, 119, 120, 121, 122, 123, 109,
	110, 111, 112, 113, 114, 115, 116, 117, 118, 80,
	0, 137, 135, 136, 132, 133, 0, 124, 130, 131,
	138, 139, 141, 140, 142, 143, 0, 0, 0, 0,
	0, 152, 48, 49, 50, 51, 0, 134, 145, 144,
	60, 61, 0, 62, 0, 46, 0, 0, 67, 170,
	174, 176, 175, 188, 189, 186, 187, 190, 191, 192,
	193, 194, 184, 185, 178, 179, 177, 180, 182, 183,
	0, 0, 0, 0, 0, 0, 42, 43, 0, 0,
	0, 0, 44, 181, 45, 40, 41, 52, 53, 54,
	55, 56, 57, 58, 59, 0, 0, 0, 39, 0,
	0, 0, 0, 20, 63, 64, 0, 0, 0, 0,
	37, 0, 0, 0, 0, 66, 0, 22, 0, 0,
	0, 0, 21, 13, 12, 0, 14, 0, 25, 0,
	26, 0, 0, 15, 0, 0, 0, 16, 17, 0,
	29, 0, 18, 28, 0, 0, 0, 0, 0, 19,
	0, 24, 0, 47, 0, 31, 152, 48, 49, 50,
	51, 0, 0, 0, 0, 60, 61, 0, 62, 188,
	189, 186, 187, 190, 191, 192, 193, 194, 184, 185,
	178, 179, 177, 180, 182, 183, 27, 9, 531, 46,
	0, 0, 67, 0, 0, 0, 0, 0, 0, 181,
	0, 42, 43, 0, 0, 0, 0, 44, 0, 45,
	40, 41, 52, 53, 54, 55, 56, 57, 58, 59,
	0, 0, 0, 39, 0, 0, 0, 0, 20, 63,
	64, 0, 0, 0, 0, 37, 0, 0, 0, 0,
	66, 0, 22, 0, 0, 0, 0, 21, 13, 12,
	0, 14, 526, 25, 0, 26, 0, 0, 15, 0,
	0, 0, 16, 17, 0, 29, 0, 18, 28, 0,
	0, 0, 0, 0, 19, 0, 24, 0, 47, 0,
	31, 152, 48, 49, 50, 51, 0, 0, 0, 0,
	60, 61, 0, 62, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 27, 9, 0, 46, 0, 0, 67, 0, 0,
	0, 0, 0, 0, 0, 0, 42, 43, 0, 0,
	0, 0, 44, 0, 45, 40, 41, 52, 53, 54,
	55, 56, 57, 58, 59, 0, 0, 0, 39, 0,
	0, 0, 0, 20, 63, 64, 0, 0, 0, 0,
	37, 0, 0, 0, 0, 66, 0, 22, 0, 0,
	0, 0, 21, 13, 12, 0, 14, 0, 25, 0,
	26, 0, 0, 15, 0, 0, 0, 16, 17, 0,
	29, 0, 18, 28, 0, 0, 0, 0, 0, 19,
	0, 24, 0, 47, 0, 31, 152, 48, 49, 50,
	51, 0, 0, 0, 0, 60, 61, 0, 62, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 27, 9, 524, 46,
	0, 0, 67, 0, 0, 0, 0, 0, 0, 0,
	0, 42, 43, 0, 0, 0, 0, 44, 0, 45,
	40, 41, 52, 53, 54, 55, 56, 57, 58, 59,
	0, 0, 0, 39, 0, 0, 0, 0, 20, 63,
	64, 0, 0, 0, 0, 37, 0, 0, 0, 0,
	66, 0, 22, 0, 0, 0, 0, 21, 13, 12,
	0, 14, 0, 25, 0, 26, 0, 0, 15, 0,
	0, 0, 16, 17, 0, 29, 0, 18, 28, 0,
	0, 0, 0, 0, 19, 0, 24, 0, 47, 0,
	31, 152, 48, 49, 50, 51, 0, 0, 0, 0,
	60, 61, 0, 62, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 27, 9, 515, 46, 0, 0, 67, 0, 0,
	0, 0, 0, 0, 0, 0, 42, 43, 0, 0,
	0, 0, 44, 0, 45, 40, 41, 52, 53, 54,
	55, 56, 57, 58, 59, 0, 0, 0, 39, 0,
	0, 0, 0, 20, 63, 64, 0, 0, 0, 0,
	37, 0, 0, 0, 0, 66, 0, 22, 0, 0,
	0, 0, 21, 13, 12, 0, 14, 0, 25, 508,
	26, 0, 0, 15, 0, 0, 0, 16, 17, 0,
	29, 0, 18, 28, 0, 0, 0, 0, 0, 19,
	0, 24, 0, 47, 0, 31, 152, 48, 49, 50,
	51, 0, 0, 0, 0, 60, 61, 0, 62, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 27, 9, 0, 46,
	0, 0, 67, 0, 0, 0, 0, 0, 0, 0,
	0, 42, 43, 0, 0, 0, 0, 44, 0, 45,
	40, 41, 52, 53, 54, 55, 56, 57, 58, 59,
	0, 0, 0, 39, 0, 0, 0, 0, 20, 63,
	64, 0, 0, 0, 0, 37, 0, 0, 0, 0,
	66, 0, 22, 0, 0, 0, 0, 21, 13, 12,
	0, 14, 0, 25, 0, 26, 468, 0, 15, 0,
	0, 0, 16, 17, 0, 29, 0, 18, 28, 0,
	0, 0, 0, 0, 19, 0, 24, 0, 47, 0,
	31, 152, 48, 49, 50, 51, 0, 0, 0, 0,
	60, 61, 0, 62, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 27, 9, 0, 46, 0, 0, 67, 0, 0,
	0, 0, 0, 0, 0, 0, 42, 43, 0, 0,
	0, 0, 44, 0, 45, 40, 41, 52, 53, 54,
	55, 56, 57, 58, 59, 0, 0, 0, 39, 0,
	0, 0, 0, 20, 63, 64, 0, 0, 0, 0,
	37, 0, 0, 0, 0, 66, 0, 22, 0, 0,
	0, 0, 21, 13, 12, 449, 14, 0, 25, 0,
	26, 0, 0, 15, 0, 0, 0, 16, 17, 0,
	29, 0, 18, 28, 0, 0, 0, 0, 0, 19,
	0, 24, 0, 47, 0, 31, 152, 48, 49, 50,
	51, 0, 0, 0, 0, 60, 61, 0, 62, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 27, 9, 0, 46,
	0, 0, 67, 0, 0, 0, 0, 0, 0, 0,
	0, 42, 43, 0, 0, 0, 0, 44, 0, 45,
	40, 41, 52, 53, 54, 55, 56, 57, 58, 59,
	0, 0, 0, 39, 0, 0, 0, 412, 20, 63,
	64, 0, 0, 0, 0, 37, 0, 0, 0, 0,
	66, 0, 22, 0, 0, 0, 0, 21, 13, 12,
	0, 14, 0, 25, 0, 26, 0, 0, 15, 0,
	0, 0, 16, 17, 0, 29, 0, 18, 28, 0,
	0, 0, 0, 0, 19, 0, 24, 0, 47, 0,
	31, 152, 48, 49, 50, 51, 0, 0, 0, 0,
	60, 61, 0, 62, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 27, 9, 0, 46, 0, 0, 67, 0, 0,
	0, 0, 0, 0, 0, 0, 42, 43, 0, 0,
	0, 0, 44, 0, 45, 40, 41, 52, 53, 54,
	55, 56, 57, 58, 59, 0, 0, 0, 39, 0,
	0, 0, 0, 20, 63, 64, 0, 0, 0, 0,
	37, 0, 0, 0, 0, 66, 0, 22, 0, 0,
	0, 0, 21, 13, 12, 0, 14, 0, 25, 0,
	26, 0, 0, 15, 0, 0, 0, 16, 17, 0,
	29, 0, 18, 28, 0, 0, 0, 0, 0, 19,
	0, 24, 0, 47, 0, 31, 152, 48, 49, 50,
	51, 0, 0, 0, 0, 60, 61, 0, 62, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 27, 9, 360, 46,
	0, 0, 67, 0, 0, 0, 0, 0, 0, 0,
	0, 42, 43, 0, 0, 0, 0, 44, 0, 45,
	40, 41, 52, 53, 54, 55, 56, 57, 58, 59,
	0, 0, 0, 39, 0, 0, 0, 0, 20, 63,
	64, 0, 0, 0, 0, 37, 0, 0, 0, 0,
	66, 0, 22, 0, 0, 0, 0, 21, 13, 12,
	0, 14, 0, 25, 0, 26, 0, 0, 15, 0,
	0, 0, 16, 17, 0, 29, 0, 18, 28, 0,
	0, 0, 0, 0, 19, 0, 24, 0, 47, 0,
	31, 6, 48, 49, 50, 51, 0, 0, 0, 0,
	60, 61, 0, 62, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 27, 9, 257, 46, 0, 0, 67, 0, 0,
	0, 0, 0, 0, 0, 0, 42, 43, 0, 0,
	0, 0, 44, 0, 45, 40, 41, 52, 53, 54,
	55, 56, 57, 58, 59, 0, 0, 0, 39, 0,
	0, 0, 0, 20, 63, 64, 0, 0, 0, 0,
	37, 0, 0, 0, 0, 66, 0, 22, 0, 0,
	0, 0, 21, 13, 12, 0, 14, 0, 25, 0,
	26, 0, 0, 15, 0, 0, 0, 16, 17, 0,
	29, 0, 18, 28, 0, 0, 0, 0, 0, 19,
	0, 24, 0, 47, 0, 31, 152, 48, 49, 50,
	51, 0, 0, 0, 0, 60, 61, 0, 62, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 7, 0, 0, 0, 0, 27, 9, 0, 46,
	0, 0, 67, 0, 0, 0, 0, 0, 0, 0,
	0, 42, 43, 0, 0, 0, 0, 44, 0, 45,
	40, 41, 52, 53, 54, 55, 56, 57, 58, 59,
	0, 0, 0, 39, 0, 0, 0, 0, 20, 63,
	64, 0, 0, 0, 0, 37, 0, 0, 0, 0,
	66, 0, 22, 0, 0, 0, 0, 21, 13, 12,
	0, 14, 0, 25, 0, 26, 0, 0, 15, 0,
	0, 0, 16, 17, 0, 29, 0, 18, 28, 0,
	0, 0, 0, 0, 19, 0, 24, 0, 47, 0,
	31, 152, 48, 49, 50, 51, 0, 0, 0, 0,
	60, 61, 0, 62, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 460, 0,
	0, 27, 9, 0, 46, 0, 0, 67, 0, 0,
	0, 0, 0, 0, 0, 0, 42, 43, 0, 0,
	0, 0, 44, 0, 45, 40, 41, 52, 53, 54,
	55, 56, 57, 58, 59, 0, 0, 0, 39, 0,
	0, 0, 0, 20, 0, 0, 0, 0, 0, 0,
	37, 0, 0, 0, 0, 66, 0, 22, 0, 0,
	0, 0, 21, 13, 12, 0, 14, 0, 25, 0,
	26, 0, 0, 15, 0, 0, 0, 16, 17, 0,
	0, 0, 18, 28, 0, 0, 0, 0, 0, 19,
	0, 24, 0, 47, 152, 48, 49, 50, 51, 0,
	0, 0, 0, 60, 61, 0, 62, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 504, 0, 0, 0, 0, 27, 9, 0, 46,
	0, 0, 67, 0, 0, 0, 0, 0, 0, 42,
	43, 0, 0, 0, 0, 44, 0, 45, 40, 41,
	52, 53, 54, 55, 56, 57, 58, 59, 0, 0,
	0, 39, 0, 0, 0, 0, 20, 0, 0, 0,
	0, 0, 0, 37, 0, 0, 0, 0, 66, 0,
	22, 0, 0, 0, 0, 21, 13, 12, 0, 14,
	0, 25, 0, 26, 0, 0, 15, 0, 0, 0,
	16, 17, 0, 0, 0, 18, 28, 0, 0, 0,
	0, 0, 19, 0, 24, 0, 47, 152, 48, 49,
	50, 51, 0, 0, 0, 0, 60, 61, 0, 62,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 414, 0, 0, 0, 0, 27,
	9, 0, 46, 0, 0, 67, 0, 0, 0, 0,
	0, 0, 42, 43, 0, 0, 0, 0, 44, 0,
	45, 40, 41, 52, 53, 54, 55, 56, 57, 58,
	59, 0, 0, 0, 39, 0, 0, 0, 0, 20,
	0, 0, 0, 0, 0, 0, 37, 0, 0, 0,
	0, 66, 0, 22, 0, 0, 0, 0, 21, 13,
	12, 0, 14, 0, 25, 0, 26, 0, 0, 15,
	0, 0, 0, 16, 17, 0, 0, 0, 18, 28,
	0, 0, 0, 0, 0, 19, 0, 24, 0, 47,
	152, 48, 49, 50, 51, 0, 0, 0, 0, 60,
	61, 0, 62, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 392, 0, 0,
	0, 0, 27, 9, 0, 46, 0, 0, 67, 0,
	0, 0, 0, 0, 0, 42, 43, 0, 0, 0,
	0, 44, 0, 45, 40, 41, 52, 53, 54, 55,
	56, 57, 58, 59, 0, 0, 0, 39, 0, 0,
	0, 0, 20, 0, 0, 0, 0, 0, 0, 37,
	0, 0, 0, 0, 66, 0, 22, 0, 0, 0,
	0, 21, 13, 12, 0, 14, 0, 25, 0, 26,
	0, 0, 15, 0, 0, 0, 16, 17, 0, 0,
	0, 18, 28, 0, 0, 0, 0, 0, 19, 0,
	24, 0, 47, 152, 48, 49, 50, 51, 0, 0,
	0, 0, 60, 61, 0, 62, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	375, 0, 0, 0, 0, 27, 9, 0, 46, 0,
	0, 67, 0, 0, 0, 0, 0, 0, 42, 43,
	0, 0, 0, 0, 44, 0, 45, 40, 41, 52,
	53, 54, 55, 56, 57, 58, 59, 0, 0, 0,
	39, 0, 0, 0, 0, 20, 0, 0, 0, 0,
	0, 0, 37, 0, 0, 0, 0, 66, 0, 22,
	0, 0, 0, 0, 21, 13, 12, 0, 14, 0,
	25, 0, 26, 0, 0, 15, 0, 0, 0, 16,
	17, 0, 0, 0, 18, 28, 0, 0, 0, 0,
	0, 19, 0, 24, 0, 47, 152, 48, 49, 50,
	51, 0, 0, 0, 0, 60, 61, 0, 62, 175,
	188, 189, 186, 187, 190, 191, 192, 193, 194, 184,
	185, 178, 179, 177, 180, 182, 183, 0, 27, 9,
	0, 46, 0, 0, 67, 0, 0, 0, 0, 0,
	181, 42, 43, 0, 0, 0, 0, 44, 0, 45,
	40, 41, 52, 53, 54, 55, 56, 57, 58, 59,
	0, 0, 0, 39, 0, 0, 0, 0, 20, 0,
	0, 0, 0, 0, 0, 37, 0, 0, 0, 0,
	66, 0, 22, 0, 0, 0, 0, 21, 13, 12,
	0, 14, 0, 25, 0, 26, 0, 0, 15, 0,
	0, 0, 16, 17, 0, 0, 0, 18, 28, 0,
	0, 0, 0, 0, 19, 0, 24, 0, 47, 0,
	152, 48, 49, 50, 51, 0, 0, 0, 0, 60,
	61, 0, 62, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 27, 9, 432, 46, 0, 0, 67, 0, 0,
	152, 48, 49, 50, 51, 42, 43, 0, 0, 60,
	61, 44, 62, 45, 40, 41, 52, 53, 54, 55,
	56, 57, 58, 59, 0, 0, 0, 39, 0, 0,
	0, 0, 0, 492, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 66, 42, 43, 0, 0, 0,
	0, 44, 0, 45, 40, 41, 52, 53, 54, 55,
	56, 57, 58, 59, 0, 0, 0, 39, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 47, 0, 66, 0, 0, 0, 0, 0,
	433, 0, 152, 48, 49, 50, 51, 0, 0, 0,
	0, 60, 61, 0, 62, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 46, 0,
	0, 67, 47, 0, 0, 323, 0, 0, 0, 0,
	493, 0, 0, 0, 0, 0, 0, 42, 43, 0,
	0, 0, 0, 44, 0, 45, 40, 41, 52, 53,
	54, 55, 56, 57, 58, 59, 0, 0, 46, 39,
	0, 67, 152, 48, 49, 50, 51, 0, 0, 0,
	0, 60, 61, 0, 62, 0, 66, 0, 0, 0,
	0, 152, 48, 49, 50, 51, 0, 0, 0, 304,
	60, 61, 0, 62, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 42, 43, 0,
	0, 0, 0, 44, 47, 45, 40, 41, 52, 53,
	54, 55, 56, 57, 58, 59, 42, 43, 0, 39,
	0, 0, 44, 0, 45, 40, 41, 52, 53, 54,
	55, 56, 57, 58, 59, 0, 66, 0, 39, 0,
	46, 0, 0, 67, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 66, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 47, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 47, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	46, 0, 0, 67, 171, 173, 172, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 46,
	0, 0, 67, 0, 195, 0, 196, 169, 170, 174,
	176, 175, 188, 189, 186, 187, 190, 191, 192, 193,
	194, 184, 185, 178, 179, 177, 180, 182, 183, 171,
	173, 172, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 181, 0, 0, 0, 0, 0, 0, 195,
	0, 196, 169, 170, 174, 176, 175, 188, 189, 186,
	187, 190, 191, 192, 193, 194, 184, 185, 178, 179,
	177, 180, 182, 183, 171, 173, 172, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 181, 0, 0,
	0, 0, 0, 0, 195, 0, 196, 169, 170, 174,
	176, 175, 188, 189, 186, 187, 190, 191, 192, 193,
	194, 184, 185, 178, 179, 177, 180, 182, 183, 171,
	173, 172, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 181, 0, 0, 0, 0, 411, 0, 195,
	0, 196, 169, 170, 174, 176, 175, 188, 189, 186,
	187, 190, 191, 192, 193, 194, 184, 185, 178, 179,
	177, 180, 182, 183, 171, 173, 172, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 181, 0, 0,
	0, 0, 410, 0, 195, 0, 196, 169, 170, 174,
	176, 175, 188, 189, 186, 187, 190, 191, 192, 193,
	194, 184, 185, 178, 179, 177, 180, 182, 183, 171,
	173, 172, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 181, 0, 0, 0, 0, 370, 0, 195,
	0, 196, 169, 170, 174, 176, 175, 188, 189, 186,
	187, 190, 191, 192, 193, 194, 184, 185, 178, 179,
	177, 180, 182, 183, 171, 173, 172, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 181, 0, 0,
	0, 0, 369, 0, 195, 0, 196, 169, 170, 174,
	176, 175, 188, 189, 186, 187, 190, 191, 192, 193,
	194, 184, 185, 178, 179, 177, 180, 182, 183, 171,
	173, 172, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 181, 0, 0, 0, 0, 368, 0, 195,
	0, 196, 169, 170, 174, 176, 175, 188, 189, 186,
	187, 190, 191, 192, 193, 194, 184, 185, 178, 179,
	177, 180, 182, 183, 171, 173, 172, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 181, 0, 0,
	0, 0, 347, 0, 195, 0, 196, 169, 170, 174,
	176, 175, 188, 189, 186, 187, 190, 191, 192, 193,
	194, 184, 185, 178, 179, 177, 180, 182, 183, 171,
	173, 172, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 181, 0, 0, 0, 0, 343, 0, 195,
	482, 196, 169, 170, 174, 176, 175, 188, 189, 186,
	187, 190, 191, 192, 193, 194, 184, 185, 178, 179,
	177, 180, 182, 183, 171, 173, 172, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 181, 0, 0,
	0, 0, 337, 0, 195, 0, 196, 169, 170, 174,
	176, 175, 188, 189, 186, 187, 190, 191, 192, 193,
	194, 184, 185, 178, 179, 177, 180, 182, 183, 171,
	173, 172, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 181, 0, 0, 372, 0, 0, 0, 195,
	0, 196, 169, 170, 174, 176, 175, 188, 189, 186,
	187, 190, 191, 192, 193, 194, 184, 185, 178, 179,
	177, 180, 182, 183, 171, 173, 172, 0, 0, 465,
	0, 0, 0, 0, 0, 0, 0, 181, 483, 0,
	0, 0, 0, 0, 195, 0, 196, 169, 170, 174,
	176, 175, 188, 189, 186, 187, 190, 191, 192, 193,
	194, 184, 185, 178, 179, 177, 180, 182, 183, 171,
	173, 172, 0, 0, 356, 0, 0, 0, 0, 0,
	0, 0, 181, 168, 0, 0, 0, 0, 0, 195,
	352, 196, 169, 170, 174, 176, 175, 188, 189, 186,
	187, 190, 191, 192, 193, 194, 184, 185, 178, 179,
	177, 180, 182, 183, 171, 173, 172, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 181, 0, 0,
	0, 0, 0, 0, 195, 0, 196, 169, 170, 174,
	176, 175, 188, 189, 186, 187, 190, 191, 192, 193,
	194, 184, 185, 178, 179, 177, 180, 182, 183, 173,
	172, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 181, 0, 0, 0, 0, 0, 195, 0,
	196, 169, 170, 174, 176, 175, 188, 189, 186, 187,
	190, 191, 192, 193, 194, 184, 185, 178, 179, 177,
	180, 182, 183, 172, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 181, 0, 0, 0,
	0, 195, 0, 196, 169, 170, 174, 176, 175, 188,
	189, 186, 187, 190, 191, 192, 193, 194, 184, 185,
	178, 179, 177, 180, 182, 183, 340, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 181,
	0, 195, 0, 196, 169, 170, 174, 176, 175, 188,
	189, 186, 187, 190, 191, 192, 193, 194, 184, 185,
	178, 179, 177, 180, 182, 183, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 195, 181,
	196, 169, 170, 174, 176, 175, 188, 189, 186, 187,
	190, 191, 192, 193, 194, 184, 185, 178, 179, 177,
	180, 182, 183, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 181, 196, 169, 170,
	174, 176, 175, 188, 189, 186, 187, 190, 191, 192,
	193, 194, 184, 185, 178, 179, 177, 180, 182, 183,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 181, 174, 176, 175, 188, 189, 186,
	187, 190, 191, 192, 193, 194, 184, 185, 178, 179,
	177, 180, 182, 183, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 181, 176, 175,
	188, 189, 186, 187, 190, 191, 192, 193, 194, 184,
	185, 178, 179, 177, 180, 182, 183, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	181,
}
var yyPact = [...]int{

	-1000, -1000, 1877, -1000, -1000, -1000, 483, 159, -1000, -1000,
	-1000, -1000, -30, 2742, -31, -33, 3087, 3087, 3087, -24,
	152, 3087, -1000, 3674, -34, -36, -37, -1000, -12, 231,
	133, 171, 189, 185, 380, -1000, -1000, -39, -1000, 3087,
	-24, -24, 3087, 3087, 3087, 3087, 3087, -64, 3087, -69,
	3087, 3087, 3087, 3087, 3087, 3087, 3087, 3087, 3087, 3087,
	3087, 3087, 3087, -1000, -1000, -1000, -1000, -38, 48, 3854,
	-1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, 3087,
	-64, 3087, 3087, -69, 3087, 3087, 3087, 3087, -1000, -1000,
	-1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000,
	-1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000,
	-1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000,
	-1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000,
	-1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000,
	-1000, -1000, -1000, -1000, -1000, -1000, 47, 52, -1000, 1752,
	3087, 134, 3087, 3087, 3087, 46, 3854, 45, 44, 138,
	-1000, -1000, 137, -1000, 278, 82, -1000, 3854, -1000, 3087,
	3087, 3087, 3087, 3087, 3087, 3087, 3087, 3087, 3087, 3087,
	3087, 3087, 3087, 3087, 3087, 3087, 3087, 3087, 3087, 3087,
	3087, 3087, 3087, 3087, 3087, 3068, 3087, -24, 3087, 160,
	-1000, 170, -1000, 169, -1000, -17, -70, 2742, -73, 42,
	241, 2998, 3087, 3087, 3087, 3087, 3087, 3087, 3087, 3087,
	3087, 3087, 3087, 3087, -1000, -1000, 3087, -1000, -1000, -1000,
	197, 197, 197, 197, 3539, 3087, 3854, 3087, 3854, 3854,
	197, 197, 197, 197, 197, 197, 197, 197, 4018, 3981,
	4018, 3087, -1000, -1000, -1000, 168, -1000, -1000, -1000, -1000,
	-1000, 3494, -86, 41, 306, 3854, 3449, -1000, -1000, -1000,
	-1000, -24, -1000, 152, 3087, -1000, 3087, 615, 4089, 3898,
	4018, 3941, 4122, 731, 2722, 283, 283, 283, 197, 197,
	197, 197, 280, 280, 235, 235, 235, 235, 235, 259,
	259, 259, 259, 3809, 3087, 4055, 305, -1000, -1000, 3719,
	63, -1000, 277, 1627, -87, -20, -27, 3087, -1000, 3087,
	-1000, -1000, 4018, 3087, 4018, 4018, 4018, 4018, 4018, 4018,
	4018, 4018, 4018, 4018, 4018, 4018, 3404, -1000, 3359, 3314,
	3087, 3584, -1000, 2619, 3087, 3087, 3087, 93, -1000, -1000,
	3854, -1000, 3087, 4055, -96, -24, -4, 2496, 160, 3087,
	-1000, 112, -28, -1000, 3269, 3224, 1502, 731, 2373, -1000,
	-1000, 4018, -1000, -1000, -1000, -1000, 67, 10, 3854, -1000,
	8, 6, 4055, 3, -1000, 66, -1000, -24, -88, 2866,
	-1000, -1000, -1000, -1000, 3854, 116, -97, 293, -1000, 230,
	-1000, -1000, 9, -1000, -1000, -1000, -1000, 159, 11, -1000,
	2742, 240, 1, -1000, -1000, 1377, 0, 3087, -67, -1000,
	142, -1000, -1000, 2127, -4, -1000, 2866, -135, 267, -1000,
	-1000, 3764, -24, -89, 1252, -1000, -91, -21, 239, 112,
	50, -1000, -1000, -1000, 159, -1000, -1000, -1000, 2002, -1,
	-1000, -124, -1000, 3087, 105, -71, -2, 135, -1000, -1000,
	-1000, -127, -128, -1000, 2866, 2906, -1000, 2866, -3, 78,
	-1000, -22, 112, -1000, 151, -1000, -1000, 2002, -1000, 2250,
	3629, -1000, -1000, -1000, -1000, -1000, -7, 1127, 2127, -1000,
	-1000, 3854, -24, -92, -131, -1000, 202, -1000, 1002, -1000,
	-1000, 274, -1000, -1000, -1000, -1000, 2002, -1000, -9, -1000,
	-1000, 2866, -1000, -132, 78, -1000, 877, 3087, 752, 2002,
	-1000, -133, -23, -1000, -1000, 3854, -10, -1000, -1000, -1000,
	627, -1000,
}
var yyPgo = [...]int{

	0, 273, 387, 386, 385, 382, 381, 13, 380, 4,
	379, 20, 376, 1, 375, 322, 316, 373, 371, 6,
	11, 370, 369, 9, 0, 368, 367, 27, 28, 366,
	365, 363, 362, 361, 12, 359, 357, 356, 14, 274,
	355, 26, 354, 25, 352, 24, 350, 16, 10, 2,
	8, 349, 344, 3, 343, 15, 342, 340, 339, 338,
	328, 326, 321, 317, 5,
}
var yyR1 = [...]int{

	0, 60, 61, 61, 61, 61, 61, 61, 61, 61,
	61, 61, 61, 61, 61, 61, 61, 61, 61, 61,
	61, 61, 61, 61, 61, 61, 61, 61, 61, 61,
	61, 61, 61, 61, 61, 61, 61, 61, 61, 61,
	61, 61, 61, 61, 61, 61, 61, 61, 61, 61,
	61, 61, 61, 61, 61, 61, 61, 61, 61, 61,
	61, 61, 61, 61, 61, 61, 61, 61, 61, 62,
	62, 62, 62, 62, 62, 62, 5, 5, 8, 8,
	7, 9, 9, 9, 10, 10, 6, 6, 6, 6,
	6, 13, 13, 12, 12, 12, 11, 11, 11, 11,
	11, 11, 11, 11, 11, 11, 11, 11, 11, 11,
	11, 11, 11, 11, 11, 11, 11, 57, 57, 58,
	58, 59, 59, 54, 54, 55, 56, 56, 29, 29,
	30, 30, 31, 31, 32, 32, 33, 33, 34, 34,
	35, 35, 37, 37, 37, 37, 38, 38, 38, 64,
	64, 36, 36, 48, 48, 48, 48, 49, 50, 50,
	51, 51, 52, 52, 52, 52, 52, 52, 53, 53,
	40, 40, 41, 42, 42, 43, 43, 44, 44, 45,
	46, 46, 47, 63, 63, 15, 15, 14, 14, 1,
	1, 16, 21, 21, 22, 22, 23, 23, 17, 17,
	4, 4, 2, 2, 3, 3, 19, 19, 20, 20,
	20, 18, 18, 25, 25, 25, 25, 25, 25, 25,
	25, 25, 25, 25, 25, 25, 25, 25, 25, 25,
	25, 25, 25, 25, 25, 25, 25, 25, 25, 25,
	25, 25, 25, 25, 25, 25, 25, 25, 25, 25,
	25, 25, 25, 25, 25, 25, 25, 25, 25, 25,
	25, 25, 25, 25, 25, 25, 25, 25, 25, 25,
	25, 25, 25, 25, 25, 25, 25, 25, 25, 25,
	25, 25, 25, 25, 25, 24, 24, 39, 39, 26,
	27, 28, 28, 28,
}
var yyR2 = [...]int{

	0, 1, 1, 1, 1, 1, 1, 1, 1, 1,
	1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
	1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
	1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
	1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
	1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
	1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
	1, 1, 1, 1, 1, 1, 1, 1, 1, 3,
	1, 1, 2, 3, 2, 0, 1, 1, 3, 3,
	1, 2, 0, 1, 1, 1, 3, 1, 1, 5,
	7, 9, 5, 3, 3, 3, 3, 3, 3, 1,
	2, 6, 7, 9, 5, 1, 6, 0, 9, 1,
	3, 0, 4, 3, 1, 3, 1, 4, 5, 6,
	1, 3, 6, 7, 3, 6, 1, 4, 0, 1,
	3, 1, 3, 4, 4, 5, 0, 5, 4, 1,
	1, 1, 4, 1, 2, 4, 3, 1, 0, 1,
	3, 1, 3, 1, 4, 2, 6, 4, 1, 4,
	3, 1, 1, 3, 1, 1, 3, 3, 1, 1,
	1, 3, 1, 0, 1, 5, 4, 1, 2, 1,
	1, 10, 1, 0, 1, 3, 4, 6, 0, 1,
	0, 1, 0, 1, 0, 1, 1, 2, 1, 1,
	1, 0, 2, 3, 4, 2, 3, 3, 3, 3,
	3, 3, 3, 3, 3, 3, 3, 3, 2, 2,
	2, 2, 3, 3, 3, 3, 3, 3, 3, 3,
	3, 3, 3, 3, 3, 3, 3, 3, 3, 2,
	2, 2, 2, 3, 3, 3, 3, 3, 3, 3,
	3, 3, 3, 5, 4, 3, 4, 2, 2, 4,
	2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
	2, 1, 2, 4, 2, 1, 1, 0, 1, 1,
	1, 1, 4, 2,
}
var yyChk = [...]int{

	-1000, -60, -10, -6, -11, -16, 4, 154, -15, 160,
	-30, -32, 97, 96, 99, 106, 110, 111, 115, 122,
	76, 95, 90, -24, 124, 101, 103, 159, 116, 113,
	-14, 128, -29, -31, -27, -25, -1, 83, -26, 71,
	58, 59, 49, 50, 55, 57, 162, 126, 5, 6,
	7, 8, 60, 61, 62, 63, 64, 65, 66, 67,
	13, 14, 16, 77, 78, -28, 88, 165, -5, -24,
	86, -62, -61, 76, 77, 78, 79, 80, 81, 71,
	126, 4, 5, 6, 7, 8, 13, 14, 10, 11,
	12, 56, 70, 82, 83, 73, 74, 75, 95, 96,
	97, 98, 99, 100, 101, 102, 103, 104, 105, 116,
	117, 118, 119, 120, 121, 122, 123, 124, 125, 111,
	112, 113, 114, 115, 134, 106, 107, 108, 109, 110,
	135, 136, 131, 132, 154, 129, 130, 128, 137, 138,
	140, 139, 141, 142, 156, 155, -7, -8, 86, -13,
	162, -11, 4, 162, 162, -39, -24, -39, -39, -40,
	-41, -28, -42, -43, 88, -44, -45, -24, 159, 33,
	34, 10, 12, 11, 35, 37, 36, 51, 49, 50,
	52, 68, 53, 54, 47, 48, 40, 41, 38, 39,
	42, 43, 44, 45, 46, 30, 32, 162, 162, 162,
	160, -4, 37, 128, -1, 86, 73, 74, 73, 75,
	74, 17, 18, 19, 20, 29, 21, 22, 23, 24,
	25, 26, 27, 28, 58, 59, 162, -24, -27, -27,
	-24, -24, -24, -24, -24, 162, -24, 162, -24, -24,
	-24, -24, -24, -24, -24, -24, -24, -24, -24, -24,
	-24, 160, -28, 159, 159, 157, -12, 161, -11, -16,
	-15, -24, 97, -34, -35, -24, -24, 159, 159, 159,
	159, 9, 159, 9, 17, 159, 9, -24, -24, -24,
	-24, -24, -24, -24, -24, -24, -24, -24, -24, -24,
	-24, -24, -24, -24, -24, -24, -24, -24, -24, -24,
	-24, -24, -24, -24, 31, -24, -46, -47, -27, -24,
	-54, -55, 86, -13, 86, 86, 160, 162, -11, 162,
	159, 31, -24, 37, -24, -24, -24, -24, -24, -24,
	-24, -24, -24, -24, -24, -24, -24, 163, -24, -24,
	15, -24, 86, 163, 162, 159, 9, 163, -41, -43,
	-24, -45, 31, -24, -63, 9, 105, 163, 9, 17,
	161, 162, 160, 161, -24, -24, -13, -24, 163, 163,
	163, -24, 161, -33, -11, 31, -24, -34, -24, -37,
	160, 31, -24, 163, -47, -48, -27, 37, 134, 69,
	-56, -11, 31, -55, -24, -57, -21, -22, -23, -17,
	-19, -20, 30, -9, 135, 136, -7, 157, 154, 161,
	163, 163, 75, -11, 31, -13, 163, 159, -38, 159,
	-38, 159, 159, 163, 15, -27, 162, -49, -51, -50,
	-52, -24, 37, 134, -13, -59, 117, 118, 163, 9,
	-2, 37, -20, -7, 157, -11, 31, 159, -13, 98,
	159, -34, 161, 108, 109, -38, 107, -38, -53, -11,
	31, -48, -49, 164, 9, 15, -27, 162, 104, 162,
	160, -18, 31, -23, -3, 158, -7, -13, 159, 163,
	-24, -64, 31, 159, 161, 159, 107, -13, 163, 163,
	-50, -24, 37, 134, -49, 159, -58, -9, -13, 160,
	-19, 88, -36, -11, 31, -64, -13, 159, 102, -53,
	-27, 162, 163, 88, 35, 161, -13, 17, -13, -13,
	159, -49, 163, -9, 161, -24, 100, 163, 160, 159,
	-13, 161,
}
var yyDef = [...]int{

	85, -2, 1, 84, 86, 87, 0, 0, 90, 92,
	97, 98, 0, 0, 0, 0, 287, 287, 287, 0,
	0, 0, 109, 0, 0, 0, 0, 115, 0, 200,
	0, 0, 130, 0, 285, 286, 187, 0, 290, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 281, 0, 189, 190, 289, 291, 0, 0, 267,
	76, 77, 69, 70, 71, 72, 73, 74, 75, 12,
	39, 2, 3, 4, 5, 6, 45, -2, 7, 8,
	9, 10, 11, 13, 14, 15, 16, 17, 18, 19,
	20, 21, 22, 23, 24, 25, 26, 27, 28, 29,
	30, 31, 32, 33, 34, 35, 36, 37, 38, 40,
	41, 42, 43, 44, 47, 48, 49, 50, 51, 52,
	53, 54, 55, 56, 57, 58, 59, 60, 61, 62,
	63, 64, 65, 66, 67, 68, 0, 80, 78, 0,
	0, 0, 0, 138, 0, 0, 288, 0, 0, 0,
	171, 172, 0, 174, 175, 0, 178, 179, 110, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	92, 0, 201, 0, 188, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 228, 230, 0, 215, 229, 231,
	249, 250, 251, 252, 0, 0, 268, 0, 270, 271,
	272, 273, 274, 275, 276, 277, 278, 279, 280, 282,
	284, 0, 293, 88, 89, 0, 91, 96, 93, 94,
	95, 0, 0, 0, 139, 141, 0, 103, 104, 105,
	106, 0, 107, 0, 0, 108, 0, 232, 233, 234,
	235, 236, 237, 238, 239, 240, 241, 242, 243, 244,
	245, 246, 247, 248, -2, -2, -2, -2, -2, -2,
	-2, -2, -2, 0, 0, 265, 183, 180, 182, 0,
	0, 124, 0, 0, 0, 0, 0, 0, 131, 0,
	134, 92, 213, 0, 216, 217, 218, 219, 220, 221,
	222, 223, 224, 225, 226, 227, 0, 262, 0, 0,
	0, 0, 79, 0, 0, 138, 0, 0, 170, 173,
	176, 177, 0, 264, 0, 184, 0, 0, 0, 0,
	117, -2, 0, 186, 0, 0, 0, 214, 0, 266,
	269, 283, 292, 99, 136, 92, 0, 0, 140, 102,
	146, 146, 263, 0, 181, 0, 153, 0, 0, 158,
	114, 126, 92, 123, 125, 121, 0, 192, 194, 202,
	199, 206, 0, 208, 209, 210, 81, 0, 0, 185,
	0, 0, 0, 128, 92, 0, 0, 138, 0, 146,
	0, 146, 111, 0, 0, 154, 158, 0, 157, 161,
	159, 163, 0, 0, 0, 116, 0, 0, 211, 198,
	204, 203, 207, 82, 0, 129, 92, 135, 132, 0,
	100, 0, 142, 0, 0, 0, 0, 0, 112, 168,
	92, 0, 0, 156, 158, 0, 165, 158, 0, 0,
	92, 0, 0, 195, 0, 205, 83, 133, 137, 0,
	0, 92, 149, 150, 143, 144, 0, 0, 0, 155,
	160, 162, 0, 0, 0, 127, 0, 119, 0, 92,
	212, 196, 101, 151, 92, 92, 148, 145, 0, 113,
	164, 158, 167, 0, 0, 122, 0, 0, 0, 147,
	169, 0, 0, 120, 191, 197, 0, 166, 92, 152,
	0, 118,
}
var yyTok1 = [...]int{

	1, 3, 3, 3, 3, 3, 3, 3, 3, 3,
	3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
	3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
	3, 3, 3, 55, 3, 3, 165, 54, 37, 3,
	162, 163, 52, 49, 9, 50, 51, 53, 3, 3,
	3, 3, 3, 3, 3, 3, 3, 3, 31, 159,
	43, 17, 45, 30, 67, 3, 3, 3, 3, 3,
	3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
	3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
	3, 69, 3, 164, 36, 3, 3, 3, 3, 3,
	3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
	3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
	3, 3, 3, 160, 35, 161, 57,
}
var yyTok2 = [...]int{

	2, 3, 4, 5, 6, 7, 8, 10, 11, 12,
	13, 14, 15, 16, 18, 19, 20, 21, 22, 23,
	24, 25, 26, 27, 28, 29, 32, 33, 34, 38,
	39, 40, 41, 42, 44, 46, 47, 48, 56, 58,
	59, 60, 61, 62, 63, 64, 65, 66, 68, 70,
	71, 72, 73, 74, 75, 76, 77, 78, 79, 80,
	81, 82, 83, 84, 85, 86, 87, 88, 89, 90,
	91, 92, 93, 94, 95, 96, 97, 98, 99, 100,
	101, 102, 103, 104, 105, 106, 107, 108, 109, 110,
	111, 112, 113, 114, 115, 116, 117, 118, 119, 120,
	121, 122, 123, 124, 125, 126, 127, 128, 129, 130,
	131, 132, 133, 134, 135, 136, 137, 138, 139, 140,
	141, 142, 143, 144, 145, 146, 147, 148, 149, 150,
	151, 152, 153, 154, 155, 156, 157, 158,
}
var yyTok3 = [...]int{
	0,
}

var yyErrorMessages = [...]struct {
	state int
	token int
	msg   string
}{}

//line yaccpar:1

/*	parser for yacc output	*/

var (
	yyDebug        = 0
	yyErrorVerbose = false
)

type yyLexer interface {
	Lex(lval *yySymType) int
	Error(s string)
}

type yyParser interface {
	Parse(yyLexer) int
	Lookahead() int
}

type yyParserImpl struct {
	lval  yySymType
	stack [yyInitialStackSize]yySymType
	char  int
}

func (p *yyParserImpl) Lookahead() int {
	return p.char
}

func yyNewParser() yyParser {
	return &yyParserImpl{}
}

const yyFlag = -1000

func yyTokname(c int) string {
	if c >= 1 && c-1 < len(yyToknames) {
		if yyToknames[c-1] != "" {
			return yyToknames[c-1]
		}
	}
	return __yyfmt__.Sprintf("tok-%v", c)
}

func yyStatname(s int) string {
	if s >= 0 && s < len(yyStatenames) {
		if yyStatenames[s] != "" {
			return yyStatenames[s]
		}
	}
	return __yyfmt__.Sprintf("state-%v", s)
}

func yyErrorMessage(state, lookAhead int) string {
	const TOKSTART = 4

	if !yyErrorVerbose {
		return "syntax error"
	}

	for _, e := range yyErrorMessages {
		if e.state == state && e.token == lookAhead {
			return "syntax error: " + e.msg
		}
	}

	res := "syntax error: unexpected " + yyTokname(lookAhead)

	// To match Bison, suggest at most four expected tokens.
	expected := make([]int, 0, 4)

	// Look for shiftable tokens.
	base := yyPact[state]
	for tok := TOKSTART; tok-1 < len(yyToknames); tok++ {
		if n := base + tok; n >= 0 && n < yyLast && yyChk[yyAct[n]] == tok {
			if len(expected) == cap(expected) {
				return res
			}
			expected = append(expected, tok)
		}
	}

	if yyDef[state] == -2 {
		i := 0
		for yyExca[i] != -1 || yyExca[i+1] != state {
			i += 2
		}

		// Look for tokens that we accept or reduce.
		for i += 2; yyExca[i] >= 0; i += 2 {
			tok := yyExca[i]
			if tok < TOKSTART || yyExca[i+1] == 0 {
				continue
			}
			if len(expected) == cap(expected) {
				return res
			}
			expected = append(expected, tok)
		}

		// If the default action is to accept or reduce, give up.
		if yyExca[i+1] != 0 {
			return res
		}
	}

	for i, tok := range expected {
		if i == 0 {
			res += ", expecting "
		} else {
			res += " or "
		}
		res += yyTokname(tok)
	}
	return res
}

func yylex1(lex yyLexer, lval *yySymType) (char, token int) {
	token = 0
	char = lex.Lex(lval)
	if char <= 0 {
		token = yyTok1[0]
		goto out
	}
	if char < len(yyTok1) {
		token = yyTok1[char]
		goto out
	}
	if char >= yyPrivate {
		if char < yyPrivate+len(yyTok2) {
			token = yyTok2[char-yyPrivate]
			goto out
		}
	}
	for i := 0; i < len(yyTok3); i += 2 {
		token = yyTok3[i+0]
		if token == char {
			token = yyTok3[i+1]
			goto out
		}
	}

out:
	if token == 0 {
		token = yyTok2[1] /* unknown char */
	}
	if yyDebug >= 3 {
		__yyfmt__.Printf("lex %s(%d)\n", yyTokname(token), uint(char))
	}
	return char, token
}

func yyParse(yylex yyLexer) int {
	return yyNewParser().Parse(yylex)
}

func (yyrcvr *yyParserImpl) Parse(yylex yyLexer) int {
	var yyn int
	var yyVAL yySymType
	var yyDollar []yySymType
	_ = yyDollar // silence set and not used
	yyS := yyrcvr.stack[:]

	Nerrs := 0   /* number of errors */
	Errflag := 0 /* error recovery flag */
	yystate := 0
	yyrcvr.char = -1
	yytoken := -1 // yyrcvr.char translated into internal numbering
	defer func() {
		// Make sure we report no lookahead when not parsing.
		yystate = -1
		yyrcvr.char = -1
		yytoken = -1
	}()
	yyp := -1
	goto yystack

ret0:
	return 0

ret1:
	return 1

yystack:
	/* put a state and value onto the stack */
	if yyDebug >= 4 {
		__yyfmt__.Printf("char %v in %v\n", yyTokname(yytoken), yyStatname(yystate))
	}

	yyp++
	if yyp >= len(yyS) {
		nyys := make([]yySymType, len(yyS)*2)
		copy(nyys, yyS)
		yyS = nyys
	}
	yyS[yyp] = yyVAL
	yyS[yyp].yys = yystate

yynewstate:
	yyn = yyPact[yystate]
	if yyn <= yyFlag {
		goto yydefault /* simple state */
	}
	if yyrcvr.char < 0 {
		yyrcvr.char, yytoken = yylex1(yylex, &yyrcvr.lval)
	}
	yyn += yytoken
	if yyn < 0 || yyn >= yyLast {
		goto yydefault
	}
	yyn = yyAct[yyn]
	if yyChk[yyn] == yytoken { /* valid shift */
		yyrcvr.char = -1
		yytoken = -1
		yyVAL = yyrcvr.lval
		yystate = yyn
		if Errflag > 0 {
			Errflag--
		}
		goto yystack
	}

yydefault:
	/* default state action */
	yyn = yyDef[yystate]
	if yyn == -2 {
		if yyrcvr.char < 0 {
			yyrcvr.char, yytoken = yylex1(yylex, &yyrcvr.lval)
		}

		/* look through exception table */
		xi := 0
		for {
			if yyExca[xi+0] == -1 && yyExca[xi+1] == yystate {
				break
			}
			xi += 2
		}
		for xi += 2; ; xi += 2 {
			yyn = yyExca[xi+0]
			if yyn < 0 || yyn == yytoken {
				break
			}
		}
		yyn = yyExca[xi+1]
		if yyn < 0 {
			goto ret0
		}
	}
	if yyn == 0 {
		/* error ... attempt to resume parsing */
		switch Errflag {
		case 0: /* brand new error */
			yylex.Error(yyErrorMessage(yystate, yytoken))
			Nerrs++
			if yyDebug >= 1 {
				__yyfmt__.Printf("%s", yyStatname(yystate))
				__yyfmt__.Printf(" saw %s\n", yyTokname(yytoken))
			}
			fallthrough

		case 1, 2: /* incompletely recovered error ... try again */
			Errflag = 3

			/* find a state where "error" is a legal shift action */
			for yyp >= 0 {
				yyn = yyPact[yyS[yyp].yys] + yyErrCode
				if yyn >= 0 && yyn < yyLast {
					yystate = yyAct[yyn] /* simulate a shift of "error" */
					if yyChk[yystate] == yyErrCode {
						goto yystack
					}
				}

				/* the current p has no shift on "error", pop stack */
				if yyDebug >= 2 {
					__yyfmt__.Printf("error recovery pops state %d\n", yyS[yyp].yys)
				}
				yyp--
			}
			/* there is no state on the stack with an error shift ... abort */
			goto ret1

		case 3: /* no shift yet; clobber input char */
			if yyDebug >= 2 {
				__yyfmt__.Printf("error recovery discards %s\n", yyTokname(yytoken))
			}
			if yytoken == yyEofCode {
				goto ret1
			}
			yyrcvr.char = -1
			yytoken = -1
			goto yynewstate /* try again in the same state */
		}
	}

	/* reduction by production yyn */
	if yyDebug >= 2 {
		__yyfmt__.Printf("reduce %v in:\n\t%v\n", yyn, yyStatname(yystate))
	}

	yynt := yyn
	yypt := yyp
	_ = yypt // guard against "declared and not used"

	yyp -= yyR2[yyn]
	// yyp is now the index of $0. Perform the default action. Iff the
	// reduced production is ε, $1 is possibly out of range.
	if yyp+1 >= len(yyS) {
		nyys := make([]yySymType, len(yyS)*2)
		copy(nyys, yyS)
		yyS = nyys
	}
	yyVAL = yyS[yyp+1]

	/* consult goto table to find next state */
	yyn = yyR1[yyn]
	yyg := yyPgo[yyn]
	yyj := yyg + yyS[yyp].yys + 1

	if yyj >= yyLast {
		yystate = yyAct[yyg]
	} else {
		yystate = yyAct[yyj]
		if yyChk[yystate] != -yyn {
			yystate = yyAct[yyg]
		}
	}
	// dummy call; replaced with literal code
	switch yynt {

	case 1:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:238
		{
			fmt.Println(yyDollar[1].node)
		}
	case 76:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:257
		{
			yyVAL.node = Node("identifier")
		}
	case 77:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:258
		{
			yyVAL.node = Node("reserved")
		}
	case 78:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:262
		{
			yyVAL.node = Node("NamespaceParts").append(Node(yyDollar[1].token))
		}
	case 79:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:263
		{
			yyVAL.node = yyDollar[1].node.append(Node(yyDollar[3].token))
		}
	case 80:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:267
		{
			yyVAL.node = yyDollar[1].node
		}
	case 81:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:271
		{
			yyVAL.node = Node("Name").append(yyDollar[1].node)
		}
	case 82:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:272
		{
			yyVAL.node = Node("Name").append(yyDollar[2].node).attribute("FullyQualified", "true")
		}
	case 83:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:273
		{
			yyVAL.node = Node("Name").append(yyDollar[3].node).attribute("Relative", "true")
		}
	case 84:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:277
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[2].node)
		}
	case 85:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser.y:278
		{
			yyVAL.node = Node("Statements")
		}
	case 86:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:282
		{
			yyVAL.node = yyDollar[1].node
		}
	case 87:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:283
		{
			yyVAL.node = yyDollar[1].node
		}
	case 88:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:284
		{
			yyVAL.node = yyDollar[2].node /*TODO: identifier stub, refactor it*/
		}
	case 89:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:285
		{
			yyVAL.node = Node("Namespace").append(yyDollar[2].node)
		}
	case 90:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:286
		{
			yyVAL.node = yyDollar[1].node
		}
	case 91:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:290
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[2].node)
		}
	case 92:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser.y:291
		{
			yyVAL.node = Node("stmt")
		}
	case 93:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:295
		{
			yyVAL.node = yyDollar[1].node
		}
	case 94:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:296
		{
			yyVAL.node = yyDollar[1].node
		}
	case 95:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:297
		{
			yyVAL.node = yyDollar[1].node
		}
	case 96:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:300
		{
			yyVAL.node = yyDollar[2].node
		}
	case 97:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:301
		{
			yyVAL.node = yyDollar[1].node
		}
	case 98:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:302
		{
			yyVAL.node = yyDollar[1].node
		}
	case 99:
		yyDollar = yyS[yypt-5 : yypt+1]
		//line parser.y:304
		{
			yyVAL.node = Node("While").
				append(Node("expr").append(yyDollar[3].node)).
				append(Node("stmt").append(yyDollar[5].node))
		}
	case 100:
		yyDollar = yyS[yypt-7 : yypt+1]
		//line parser.y:310
		{
			yyVAL.node = Node("DoWhile").
				append(Node("expr").append(yyDollar[5].node)).
				append(Node("stmt").append(yyDollar[2].node))
		}
	case 101:
		yyDollar = yyS[yypt-9 : yypt+1]
		//line parser.y:316
		{
			yyVAL.node = Node("For").
				append(Node("expr1").append(yyDollar[3].node)).
				append(Node("expr2").append(yyDollar[5].node)).
				append(Node("expr3").append(yyDollar[7].node)).
				append(Node("stmt").append(yyDollar[9].node))
		}
	case 102:
		yyDollar = yyS[yypt-5 : yypt+1]
		//line parser.y:323
		{
			yyVAL.node = Node("Switch").append(Node("expr").append(yyDollar[3].node)).append(yyDollar[5].node)
		}
	case 103:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:324
		{
			yyVAL.node = Node("Break").append(yyDollar[2].node)
		}
	case 104:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:325
		{
			yyVAL.node = Node("Continue").append(yyDollar[2].node)
		}
	case 105:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:326
		{
			yyVAL.node = Node("Return").append(yyDollar[2].node)
		}
	case 106:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:327
		{
			yyVAL.node = yyDollar[2].node
		}
	case 107:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:328
		{
			yyVAL.node = yyDollar[2].node
		}
	case 108:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:329
		{
			yyVAL.node = yyDollar[2].node
		}
	case 109:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:330
		{
			yyVAL.node = Node("Echo").append(Node("InlineHtml").attribute("value", yyDollar[1].token))
		}
	case 110:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:331
		{
			yyVAL.node = yyDollar[1].node
		}
	case 111:
		yyDollar = yyS[yypt-6 : yypt+1]
		//line parser.y:333
		{
			yyVAL.node = Node("Unset").append(yyDollar[3].node)
		}
	case 112:
		yyDollar = yyS[yypt-7 : yypt+1]
		//line parser.y:335
		{
			yyVAL.node = Node("Foreach").
				append(Node("expr").append(yyDollar[3].node)).
				append(Node("ForeachVariable").append(yyDollar[5].node)).
				append(yyDollar[7].node)
		}
	case 113:
		yyDollar = yyS[yypt-9 : yypt+1]
		//line parser.y:342
		{
			yyVAL.node = Node("Foreach").
				append(Node("expr").append(yyDollar[3].node)).
				append(Node("ForeachKey").append(yyDollar[5].node)).
				append(Node("ForeachVariable").append(yyDollar[7].node)).
				append(yyDollar[9].node)
		}
	case 114:
		yyDollar = yyS[yypt-5 : yypt+1]
		//line parser.y:349
		{
			yyVAL.node = Node("Declare").append(yyDollar[3].node).append(yyDollar[5].node)
		}
	case 115:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:350
		{
			yyVAL.node = Node("")
		}
	case 116:
		yyDollar = yyS[yypt-6 : yypt+1]
		//line parser.y:352
		{
			yyVAL.node = Node("Try").
				append(yyDollar[3].node).
				append(yyDollar[5].node).
				append(yyDollar[6].node)
		}
	case 117:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser.y:360
		{
			yyVAL.node = Node("CatchList")
		}
	case 118:
		yyDollar = yyS[yypt-9 : yypt+1]
		//line parser.y:362
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[4].node).append(Node("Variable").attribute("name", yyDollar[5].token)).append(yyDollar[8].node)
		}
	case 119:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:365
		{
			yyVAL.node = Node("CatchNameList").append(yyDollar[1].node)
		}
	case 120:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:366
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[3].node)
		}
	case 121:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser.y:370
		{
			yyVAL.node = Node("")
		}
	case 122:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:371
		{
			yyVAL.node = Node("Finnaly").append(yyDollar[3].node)
		}
	case 123:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:375
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[3].node)
		}
	case 124:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:376
		{
			yyVAL.node = Node("ConstList").append(yyDollar[1].node)
		}
	case 125:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:380
		{
			yyVAL.node = Node("Const").attribute("name", yyDollar[1].token).append(yyDollar[3].node)
		}
	case 126:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:384
		{
			yyVAL.node = yyDollar[1].node
		}
	case 127:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:385
		{
			yyVAL.node = yyDollar[2].node
		}
	case 128:
		yyDollar = yyS[yypt-5 : yypt+1]
		//line parser.y:390
		{
			yyVAL.node = Node("If").append(Node("expr").append(yyDollar[3].node)).append(Node("stmt").append(yyDollar[5].node))
		}
	case 129:
		yyDollar = yyS[yypt-6 : yypt+1]
		//line parser.y:394
		{
			yyVAL.node = yyDollar[1].node.append(Node("ElseIf").append(Node("expr").append(yyDollar[4].node)).append(Node("stmt").append(yyDollar[6].node)))
		}
	case 130:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:400
		{
			yyVAL.node = yyDollar[1].node
		}
	case 131:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:402
		{
			yyVAL.node = yyDollar[1].node.append(Node("Else").append(Node("stmt").append(yyDollar[3].node)))
		}
	case 132:
		yyDollar = yyS[yypt-6 : yypt+1]
		//line parser.y:409
		{
			yyVAL.node = Node("AltIf").append(Node("expr").append(yyDollar[3].node)).append(Node("stmt").append(yyDollar[6].node))
		}
	case 133:
		yyDollar = yyS[yypt-7 : yypt+1]
		//line parser.y:413
		{
			yyVAL.node = yyDollar[1].node.append(Node("AltElseIf").append(Node("expr").append(yyDollar[4].node)).append(Node("stmt").append(yyDollar[7].node)))
		}
	case 134:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:419
		{
			yyVAL.node = yyDollar[1].node
		}
	case 135:
		yyDollar = yyS[yypt-6 : yypt+1]
		//line parser.y:421
		{
			yyVAL.node = yyDollar[1].node.append(Node("AltElse").append(Node("stmt").append(yyDollar[4].node)))
		}
	case 136:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:427
		{
			yyVAL.node = yyDollar[1].node
		}
	case 137:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:428
		{
			yyVAL.node = yyDollar[2].node
		}
	case 138:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser.y:432
		{
			yyVAL.node = Node("")
		}
	case 139:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:433
		{
			yyVAL.node = yyDollar[1].node
		}
	case 140:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:436
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[3].node)
		}
	case 141:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:437
		{
			yyVAL.node = Node("ExpressionList").append(yyDollar[1].node)
		}
	case 142:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:441
		{
			yyVAL.node = yyDollar[2].node
		}
	case 143:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:442
		{
			yyVAL.node = yyDollar[3].node
		}
	case 144:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:443
		{
			yyVAL.node = yyDollar[2].node
		}
	case 145:
		yyDollar = yyS[yypt-5 : yypt+1]
		//line parser.y:444
		{
			yyVAL.node = yyDollar[3].node
		}
	case 146:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser.y:448
		{
			yyVAL.node = Node("CaseList")
		}
	case 147:
		yyDollar = yyS[yypt-5 : yypt+1]
		//line parser.y:450
		{
			yyVAL.node = yyDollar[1].node.append(Node("Case").append(Node("expr").append(yyDollar[3].node)).append(yyDollar[5].node))
		}
	case 148:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:454
		{
			yyVAL.node = yyDollar[1].node.append(Node("Default").append(yyDollar[4].node))
		}
	case 151:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:465
		{
			yyVAL.node = yyDollar[1].node
		}
	case 152:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:466
		{
			yyVAL.node = yyDollar[2].node
		}
	case 153:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:470
		{
			yyVAL.node = yyDollar[1].node
		}
	case 154:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:471
		{
			yyVAL.node = Node("Ref").append(yyDollar[2].node)
		}
	case 155:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:472
		{
			yyVAL.node = Node("List").append(yyDollar[3].node)
		}
	case 156:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:473
		{
			yyVAL.node = Node("ShortList").append(yyDollar[2].node)
		}
	case 157:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:477
		{ /* TODO: allow single trailing comma */
			yyVAL.node = yyDollar[1].node
		}
	case 158:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser.y:481
		{
			yyVAL.node = Node("")
		}
	case 159:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:482
		{
			yyVAL.node = yyDollar[1].node
		}
	case 160:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:487
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[3].node)
		}
	case 161:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:488
		{
			yyVAL.node = Node("ArrayPairList").append(yyDollar[1].node)
		}
	case 162:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:492
		{
			yyVAL.node = Node("ArrayElement").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 163:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:493
		{
			yyVAL.node = Node("ArrayElement").append(yyDollar[1].node)
		}
	case 164:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:494
		{
			yyVAL.node = Node("ArrayElement").append(yyDollar[1].node).append(Node("Ref").append(yyDollar[4].node))
		}
	case 165:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:495
		{
			yyVAL.node = Node("ArrayElement").append(Node("Ref").append(yyDollar[2].node))
		}
	case 166:
		yyDollar = yyS[yypt-6 : yypt+1]
		//line parser.y:497
		{
			yyVAL.node = Node("ArrayElement").
				append(yyDollar[1].node).
				append(Node("ArrayList").append(yyDollar[5].node))
		}
	case 167:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:503
		{
			yyVAL.node = Node("ArrayElement").
				append(Node("ArrayList").append(yyDollar[3].node))
		}
	case 168:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:510
		{
			yyVAL.node = yyDollar[1].node
		}
	case 169:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:511
		{
			yyVAL.node = yyDollar[2].node
		}
	case 170:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:515
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[3].node)
		}
	case 171:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:516
		{
			yyVAL.node = Node("GlobalVarList").append(yyDollar[1].node)
		}
	case 172:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:520
		{
			yyVAL.node = yyDollar[1].node
		}
	case 173:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:524
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[3].node)
		}
	case 174:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:525
		{
			yyVAL.node = Node("StaticVarList").append(yyDollar[1].node)
		}
	case 175:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:529
		{
			yyVAL.node = Node("StaticVariable").attribute("Name", yyDollar[1].token)
		}
	case 176:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:530
		{
			yyVAL.node = Node("StaticVariable").attribute("Name", yyDollar[1].token).append(Node("expr").append(yyDollar[3].node))
		}
	case 177:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:534
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[3].node)
		}
	case 178:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:535
		{
			yyVAL.node = Node("EchoList").append(yyDollar[1].node)
		}
	case 179:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:539
		{
			yyVAL.node = Node("Echo").append(yyDollar[1].node)
		}
	case 180:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:543
		{
			yyVAL.node = Node("UnsetVariablesList").append(yyDollar[1].node)
		}
	case 181:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:544
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[3].node)
		}
	case 182:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:548
		{
			yyVAL.node = yyDollar[1].node
		}
	case 185:
		yyDollar = yyS[yypt-5 : yypt+1]
		//line parser.y:557
		{
			yyVAL.node = yyDollar[1].node.attribute("name", yyDollar[3].token)
		}
	case 186:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:558
		{
			yyVAL.node = Node("Class").attribute("name", yyDollar[2].token)
		}
	case 187:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:561
		{
			yyVAL.node = Node("Class").attribute(yyDollar[1].value, "true")
		}
	case 188:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:562
		{
			yyVAL.node = yyDollar[1].node.attribute(yyDollar[2].value, "true")
		}
	case 189:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:566
		{
			yyVAL.value = "abstract"
		}
	case 190:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:567
		{
			yyVAL.value = "final"
		}
	case 191:
		yyDollar = yyS[yypt-10 : yypt+1]
		//line parser.y:572
		{
			yyVAL.node = Node("Function").
				attribute("name", yyDollar[3].token).
				attribute("returns_ref", yyDollar[2].value).
				append(yyDollar[5].node).
				append(yyDollar[7].node).
				append(yyDollar[9].node)
		}
	case 192:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:583
		{
			yyVAL.node = yyDollar[1].node
		}
	case 193:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser.y:584
		{
			yyVAL.node = Node("Parameter list")
		}
	case 194:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:587
		{
			yyVAL.node = Node("Parameter list").append(yyDollar[1].node)
		}
	case 195:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:588
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[3].node)
		}
	case 196:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:592
		{
			yyVAL.node = Node("Parameter").
				append(yyDollar[1].node).
				attribute("is_reference", yyDollar[2].value).
				attribute("is_variadic", yyDollar[3].value).
				attribute("var", yyDollar[4].token)
		}
	case 197:
		yyDollar = yyS[yypt-6 : yypt+1]
		//line parser.y:600
		{
			yyVAL.node = Node("Parameter").
				append(yyDollar[1].node).
				attribute("is_reference", yyDollar[2].value).
				attribute("is_variadic", yyDollar[3].value).
				attribute("var", yyDollar[4].token).
				append(yyDollar[6].node)
		}
	case 198:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser.y:611
		{
			yyVAL.node = Node("No type")
		}
	case 199:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:612
		{
			yyVAL.node = yyDollar[1].node
		}
	case 200:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser.y:616
		{
			yyVAL.value = "false"
		}
	case 201:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:617
		{
			yyVAL.value = "true"
		}
	case 202:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser.y:621
		{
			yyVAL.value = "false"
		}
	case 203:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:622
		{
			yyVAL.value = "true"
		}
	case 204:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser.y:626
		{
			yyVAL.value = "false"
		}
	case 205:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:627
		{
			yyVAL.value = "true"
		}
	case 206:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:631
		{
			yyVAL.node = yyDollar[1].node
		}
	case 207:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:632
		{
			yyVAL.node = yyDollar[2].node
			yyVAL.node.attribute("nullable", "true")
		}
	case 208:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:636
		{
			yyVAL.node = yyDollar[1].node
		}
	case 209:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:637
		{
			yyVAL.node = Node("array type")
		}
	case 210:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:638
		{
			yyVAL.node = Node("callable type")
		}
	case 211:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser.y:642
		{
			yyVAL.node = Node("void")
		}
	case 212:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:643
		{
			yyVAL.node = yyDollar[2].node
		}
	case 213:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:647
		{
			yyVAL.node = Node("Assign").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 214:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:648
		{
			yyVAL.node = Node("AssignRef").append(yyDollar[1].node).append(yyDollar[4].node)
		}
	case 215:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:649
		{
			yyVAL.node = Node("Clone").append(yyDollar[2].node)
		}
	case 216:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:650
		{
			yyVAL.node = Node("AssignAdd").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 217:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:651
		{
			yyVAL.node = Node("AssignSub").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 218:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:652
		{
			yyVAL.node = Node("AssignMul").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 219:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:653
		{
			yyVAL.node = Node("AssignPow").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 220:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:654
		{
			yyVAL.node = Node("AssignDiv").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 221:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:655
		{
			yyVAL.node = Node("AssignConcat").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 222:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:656
		{
			yyVAL.node = Node("AssignMod").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 223:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:657
		{
			yyVAL.node = Node("AssignAnd").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 224:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:658
		{
			yyVAL.node = Node("AssignOr").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 225:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:659
		{
			yyVAL.node = Node("AssignXor").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 226:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:660
		{
			yyVAL.node = Node("AssignShiftLeft").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 227:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:661
		{
			yyVAL.node = Node("AssignShiftRight").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 228:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:662
		{
			yyVAL.node = Node("PostIncrement").append(yyDollar[1].node)
		}
	case 229:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:663
		{
			yyVAL.node = Node("PreIncrement").append(yyDollar[2].node)
		}
	case 230:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:664
		{
			yyVAL.node = Node("PostDecrement").append(yyDollar[1].node)
		}
	case 231:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:665
		{
			yyVAL.node = Node("PreDecrement").append(yyDollar[2].node)
		}
	case 232:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:666
		{
			yyVAL.node = Node("Or").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 233:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:667
		{
			yyVAL.node = Node("And").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 234:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:668
		{
			yyVAL.node = Node("Or").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 235:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:669
		{
			yyVAL.node = Node("And").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 236:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:670
		{
			yyVAL.node = Node("Xor").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 237:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:671
		{
			yyVAL.node = Node("BitwiseOr").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 238:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:672
		{
			yyVAL.node = Node("BitwiseAnd").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 239:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:673
		{
			yyVAL.node = Node("BitwiseXor").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 240:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:674
		{
			yyVAL.node = Node("Concat").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 241:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:675
		{
			yyVAL.node = Node("Add").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 242:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:676
		{
			yyVAL.node = Node("Sub").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 243:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:677
		{
			yyVAL.node = Node("Mul").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 244:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:678
		{
			yyVAL.node = Node("Pow").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 245:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:679
		{
			yyVAL.node = Node("Div").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 246:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:680
		{
			yyVAL.node = Node("Mod").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 247:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:681
		{
			yyVAL.node = Node("ShiftLeft").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 248:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:682
		{
			yyVAL.node = Node("ShiftRight").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 249:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:683
		{
			yyVAL.node = Node("UnaryPlus").append(yyDollar[2].node)
		}
	case 250:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:684
		{
			yyVAL.node = Node("UnaryMinus").append(yyDollar[2].node)
		}
	case 251:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:685
		{
			yyVAL.node = Node("BooleanNot").append(yyDollar[2].node)
		}
	case 252:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:686
		{
			yyVAL.node = Node("BitwiseNot").append(yyDollar[2].node)
		}
	case 253:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:687
		{
			yyVAL.node = Node("Identical").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 254:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:688
		{
			yyVAL.node = Node("NotIdentical").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 255:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:689
		{
			yyVAL.node = Node("Equal").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 256:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:690
		{
			yyVAL.node = Node("NotEqual").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 257:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:691
		{
			yyVAL.node = Node("Spaceship").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 258:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:692
		{
			yyVAL.node = Node("Smaller").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 259:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:693
		{
			yyVAL.node = Node("SmallerOrEqual").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 260:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:694
		{
			yyVAL.node = Node("Greater").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 261:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:695
		{
			yyVAL.node = Node("GreaterOrEqual").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 262:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:696
		{
			yyVAL.node = yyDollar[2].node
		}
	case 263:
		yyDollar = yyS[yypt-5 : yypt+1]
		//line parser.y:697
		{
			yyVAL.node = Node("Ternary").append(yyDollar[1].node).append(yyDollar[3].node).append(yyDollar[5].node)
		}
	case 264:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:698
		{
			yyVAL.node = Node("Ternary").append(yyDollar[1].node).append(yyDollar[4].node)
		}
	case 265:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:699
		{
			yyVAL.node = Node("Coalesce").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 266:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:700
		{
			yyVAL.node = Node("Empty").append(yyDollar[3].node)
		}
	case 267:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:701
		{
			yyVAL.node = Node("Include").append(yyDollar[2].node)
		}
	case 268:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:702
		{
			yyVAL.node = Node("IncludeOnce").append(yyDollar[2].node)
		}
	case 269:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:703
		{
			yyVAL.node = Node("Eval").append(yyDollar[3].node)
		}
	case 270:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:704
		{
			yyVAL.node = Node("Require").append(yyDollar[2].node)
		}
	case 271:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:705
		{
			yyVAL.node = Node("RequireOnce").append(yyDollar[2].node)
		}
	case 272:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:706
		{
			yyVAL.node = Node("CastInt").append(yyDollar[2].node)
		}
	case 273:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:707
		{
			yyVAL.node = Node("CastDouble").append(yyDollar[2].node)
		}
	case 274:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:708
		{
			yyVAL.node = Node("CastString").append(yyDollar[2].node)
		}
	case 275:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:709
		{
			yyVAL.node = Node("CastArray").append(yyDollar[2].node)
		}
	case 276:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:710
		{
			yyVAL.node = Node("CastObject").append(yyDollar[2].node)
		}
	case 277:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:711
		{
			yyVAL.node = Node("CastBool").append(yyDollar[2].node)
		}
	case 278:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:712
		{
			yyVAL.node = Node("CastUnset").append(yyDollar[2].node)
		}
	case 279:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:713
		{
			yyVAL.node = Node("Silence").append(yyDollar[2].node)
		}
	case 280:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:715
		{
			yyVAL.node = Node("Print").append(yyDollar[2].node)
		}
	case 281:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:716
		{
			yyVAL.node = Node("Yield")
		}
	case 282:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:717
		{
			yyVAL.node = Node("Yield").append(yyDollar[2].node)
		}
	case 283:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:718
		{
			yyVAL.node = Node("Yield").append(yyDollar[2].node).append(yyDollar[4].node)
		}
	case 284:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:719
		{
			yyVAL.node = Node("YieldFrom").append(yyDollar[2].node)
		}
	case 285:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:723
		{
			yyVAL.node = yyDollar[1].node
		}
	case 286:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:724
		{
			yyVAL.node = yyDollar[1].node
		}
	case 287:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser.y:728
		{
			yyVAL.node = Node("")
		}
	case 288:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:729
		{
			yyVAL.node = yyDollar[1].node
		}
	case 289:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:733
		{
			yyVAL.node = yyDollar[1].node
		}
	case 290:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:737
		{
			yyVAL.node = yyDollar[1].node
		}
	case 291:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:741
		{
			yyVAL.node = Node("Variable").attribute("name", yyDollar[1].token)
		}
	case 292:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:742
		{
			yyVAL.node = yyDollar[3].node
		}
	case 293:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:743
		{
			yyVAL.node = Node("Variable").append(yyDollar[2].node)
		}
	}
	goto yystack /* stack new state and value */
}
